SqlColumnModel class
Constructors
- SqlColumnModel(String name, {required SqlDataType type, bool primaryKey = false, bool autoIncrement = false, bool unique = false, bool notNull = false, Object? defaultValue})
Properties
- autoIncrement → bool
-
final
- canPutDefaultValue → bool
-
no setter
- defaultValue → Object?
-
final
- getCorrectDefaultValue → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- notNull → bool
-
final
- primaryKey → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toCreate → String
-
no setter
- type → SqlDataType
-
final
- unique → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited