SqlForeignKeyModel class

Constructors

SqlForeignKeyModel(String columnForeignKey, {required String table, required String columnPrimaryKey, SqlForeignKeyRules onUpdateRule = SqlForeignKeyRules.noAction, SqlForeignKeyRules onDeleteRule = SqlForeignKeyRules.noAction})

Properties

columnForeignKey String
final
columnPrimaryKey String
final
hashCode int
The hash code for this object.
no setterinherited
onDeleteRule SqlForeignKeyRules
final
onUpdateRule SqlForeignKeyRules
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
toCreate String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited