SqlWhere class
Constructors
-
SqlWhere(List<
String> clauses, {required List clausesValues, WhereUnion whereUnion = WhereUnion.and})
Properties
-
clauses
→ List<
String> -
final
- clausesValues → List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- whereUnion → WhereUnion
-
final
Methods
-
getClauses(
{bool withText = false}) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited